@@ -207,14 +207,7 @@ gcal_application_finalize (GObject *object)
   g_free (self->uuid);
   g_clear_pointer (&self->initial_date, g_free);
 
-  if (self->provider != NULL)
-    {
-      gtk_style_context_remove_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (self->colors_provider));
-
-      gtk_style_context_remove_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (self->provider));
-      g_clear_object (&(self->provider));
-    }
-
+  g_clear_object (&(self->provider));
   g_clear_object (&self->colors_provider);
   g_clear_object (&self->settings);
 
@@ -319,7 +312,7 @@ gcal_application_command_line (GApplication            *app,
 
   self = GCAL_APPLICATION (app);
   argv = g_application_command_line_get_arguments (command_line, &argc);
-  context = g_option_context_new (N_("- Calendar management"));
+  context = g_option_context_new (N_("— Calendar management"));
   g_option_context_add_main_entries (context, gcal_application_goptions, GETTEXT_PACKAGE);
 
   error = NULL;
